You are viewing a plain text version of this content. The canonical link for it is here.
Posted to mime4j-dev@james.apache.org by mw...@apache.org on 2009/08/17 16:15:30 UTC

svn commit: r804990 - /james/mime4j/trunk/core/src/main/java/org/apache/james/mime4j/codec/DecoderUtil.java

Author: mwiederkehr
Date: Mon Aug 17 14:15:30 2009
New Revision: 804990

URL: http://svn.apache.org/viewvc?rev=804990&view=rev
Log:
parameter should be called encodedText because it represents what is called encoded-text in RFC 2047 (encoded-text is part of an encoded-word not the encoded-word itself).

Modified:
    james/mime4j/trunk/core/src/main/java/org/apache/james/mime4j/codec/DecoderUtil.java

Modified: james/mime4j/trunk/core/src/main/java/org/apache/james/mime4j/codec/DecoderUtil.java
URL: http://svn.apache.org/viewvc/james/mime4j/trunk/core/src/main/java/org/apache/james/mime4j/codec/DecoderUtil.java?rev=804990&r1=804989&r2=804990&view=diff
==============================================================================
--- james/mime4j/trunk/core/src/main/java/org/apache/james/mime4j/codec/DecoderUtil.java (original)
+++ james/mime4j/trunk/core/src/main/java/org/apache/james/mime4j/codec/DecoderUtil.java Mon Aug 17 14:15:30 2009
@@ -91,36 +91,36 @@
     }
     
     /**
      * Decodes an encoded word encoded with the 'B' encoding (described in 
      * RFC 2047) found in a header field body.
      * 
      * @param encodedWord the encoded word to decode.
      * @param charset the Java charset to use.
      * @return the decoded string.
      * @throws UnsupportedEncodingException if the given Java charset isn't 
      *         supported.
      */
-    public static String decodeB(String encodedWord, String charset) 
+    public static String decodeB(String encodedText, String charset) 
             throws UnsupportedEncodingException {
-        byte[] decodedBytes = decodeBase64(encodedWord);
+        byte[] decodedBytes = decodeBase64(encodedText);
         return new String(decodedBytes, charset);
     }
     
     /**
      * Decodes an encoded word encoded with the 'Q' encoding (described in 
      * RFC 2047) found in a header field body.
      * 
      * @param encodedWord the encoded word to decode.
      * @param charset the Java charset to use.
      * @return the decoded string.
      * @throws UnsupportedEncodingException if the given Java charset isn't 
      *         supported.
      */
-    public static String decodeQ(String encodedWord, String charset)
+    public static String decodeQ(String encodedText, String charset)
             throws UnsupportedEncodingException {
-        encodedWord = replaceUnderscores(encodedWord);
+        encodedText = replaceUnderscores(encodedText);
         
-        byte[] decodedBytes = decodeQuotedPrintable(encodedWord);
+        byte[] decodedBytes = decodeQuotedPrintable(encodedText);
         return new String(decodedBytes, charset);
     }
@@ -91,36 +91,36 @@
     
     /**
-     * Decodes an encoded word encoded with the 'B' encoding (described in 
+     * Decodes an encoded text encoded with the 'B' encoding (described in 
      * RFC 2047) found in a header field body.
      * 
@@ -91,36 +91,36 @@
      * RFC 2047) found in a header field body.
      * 
-     * @param encodedWord the encoded word to decode.
+     * @param encodedText the encoded text to decode.
      * @param charset the Java charset to use.
      * @return the decoded string.
@@ -91,36 +91,36 @@
     
     /**
-     * Decodes an encoded word encoded with the 'Q' encoding (described in 
+     * Decodes an encoded text encoded with the 'Q' encoding (described in 
      * RFC 2047) found in a header field body.
      * 
@@ -91,36 +91,36 @@
      * RFC 2047) found in a header field body.
      * 
-     * @param encodedWord the encoded word to decode.
+     * @param encodedText the encoded text to decode.
      * @param charset the Java charset to use.
      * @return the decoded string.